@@ -217,7 +217,7 @@ RDM_RECORDS_CUSTOM_VOCABULARIES = {
     'access_right': {
         'path': join(
             dirname(abspath(__file__)),
-            'restrictions', 'access_right', 'access_right.csv'
+            'restrictions', 'access_right', 'access_right_limit.csv'
         )
     }
 }
